@@ -5,7 +5,10 @@
 #' dependencies into the HTML file (via base64 encoding).
 #'
 #' @param graph : a visNetwork object
-#'
+#' @param file : File to save HTML into. See \link{saveWidget}
+#' @param selfcontained	: Whether to save the HTML as a single self-contained file (with external resources base64 encoded) or a file with external resources placed in an adjacent directory.
+#' @param background : Text string giving the html background color of the widget. Defaults to white.
+#' 
 #' @inheritParams htmlwidgets::saveWidget
 #' 
 #' @examples
@@ -17,7 +20,7 @@
 #'network <- visNetwork(nodes, edges)
 #'network
 #'
-#'network %>% visSave(file = "network.html")
+#'network %>% visSave(file = "network.html", background = "black")
 #'# same as
 #'visSave(network, file = "network.html")
 #'
@@ -27,6 +30,6 @@
 #' @seealso \link{visExport}
 #'
 #' @references See online documentation \url{http://datastorm-open.github.io/visNetwork/}
-visSave <- function(graph, file, selfcontained = TRUE) {
-  htmlwidgets::saveWidget(graph, file, selfcontained)
+visSave <- function(graph, file, selfcontained = TRUE, background = "white") {
+  htmlwidgets::saveWidget(graph, file, selfcontained = selfcontained, background = background)
 }
\ No newline at end of file
