@@ -4,7 +4,7 @@
 #' The link is based on id.
 #' 
 #'@param graph : a \code{\link{visNetworkProxy}}  object
-#' @param edges : data.frame with edges informations. See \link{visEdges}
+#'@param edges : data.frame with edges informations. See \link{visEdges}
 #' \itemize{
 #'  \item{"id"}{ : edge id, for update}
 #'  \item{"from"}{ : node id of begin of the edge}
@@ -14,6 +14,7 @@
 #'  \item{"title"}{ : tooltip of the node}
 #'  \item{...}{}
 #'}
+#'@param legend : Boolean. Update edges on legend ? Default to FALSE
 #'
 #'@seealso \link{visNodes} for nodes options, \link{visEdges} for edges options, \link{visGroups} for groups options, 
 #'\link{visLegend} for adding legend, \link{visOptions} for custom option, \link{visLayout} & \link{visHierarchicalLayout} for layout, 
@@ -30,13 +31,13 @@
 #'
 #'@export
 #'@references See online documentation \url{http://datastorm-open.github.io/visNetwork/}
-visUpdateEdges <- function(graph, edges){
+visUpdateEdges <- function(graph, edges, legend = FALSE){
 
   if(!any(class(graph) %in% "visNetwork_Proxy")){
     stop("Can't use visUpdateEdges with visNetwork object. Only within shiny & using visNetworkProxy")
   }
   
-  data <- list(id = graph$id, edges = edges)
+  data <- list(id = graph$id, edges = edges, legend = legend)
   
   graph$session$sendCustomMessage("visShinyUpdateEdges", data)
 
